@@ -64,7 +64,6 @@ MainWindow::MainWindow()
     , _pluggedController(0)
     , _menuBarInitialVisibility(true)
     , _menuBarInitialVisibilityApplied(false)
-    , _useTransparency(false)
 {
     if (!KonsoleSettings::saveGeometryOnExit()) {
         // If we are not using the global Konsole save geometry on exit,
@@ -83,8 +82,6 @@ MainWindow::MainWindow()
         }
     }
 
-    connect(KWindowSystem::self(), &KWindowSystem::compositingChanged, this, &MainWindow::updateUseTransparency);
-
     updateUseTransparency();
 
     // create actions for menus
@@ -129,11 +126,14 @@ MainWindow::MainWindow()
 
 void MainWindow::updateUseTransparency()
 {
-    bool useTranslucency = KWindowSystem::compositingActive() && _useTransparency;
+    if (!WindowSystemInfo::HAVE_TRANSPARENCY) {
+        return;
+    }
+
+    bool useTranslucency = KWindowSystem::compositingActive();
 
     setAttribute(Qt::WA_TranslucentBackground, useTranslucency);
     setAttribute(Qt::WA_NoSystemBackground, false);
-
     WindowSystemInfo::HAVE_TRANSPARENCY = useTranslucency;
 }
 
@@ -536,8 +536,9 @@ bool MainWindow::queryClose()
 
     QStringList processesRunning;
     foreach(Session *session, _viewManager->sessions()) {
-        if (!session)
+        if (!session || !session->isForegroundProcessActive()) {
             continue;
+        }
 
         const QString defaultProc = session->program().split('/').last();
         const QString currentProc = session->foregroundProcessName().split('/').last();
@@ -581,7 +582,7 @@ bool MainWindow::queryClose()
     case KMessageBox::No:
         if (_pluggedController && _pluggedController->session()) {
             disconnectController(_pluggedController);
-            _pluggedController->closeSession();
+            _pluggedController->session()->closeInNormalWay();
         }
         return false;
     case KMessageBox::Cancel:
@@ -765,11 +766,6 @@ void MainWindow::setShowQuickButtons(bool show)
     _viewManager->setShowQuickButtons(show);
 }
 
-void MainWindow::setTransparency(bool useTransparency)
-{
-    _useTransparency = useTransparency;
-}
-
 void MainWindow::activateMenuBar()
 {
     const QList<QAction*> menuActions = menuBar()->actions();
