@@ -281,6 +281,22 @@ void Pty::closePty()
     pty()->close();
 }
 
+void Pty::sendEof()
+{
+    if (pty()->masterFd() < 0) {
+        qWarning() << "Unable to get eof char attribute, terminal not connected.";
+        return;
+    }
+    struct ::termios ttyAttributes;
+    pty()->tcGetAttr(&ttyAttributes);
+    char eofChar = ttyAttributes.c_cc[VEOF];
+    if (!pty()->write(QByteArray(1, eofChar))) {
+        qWarning() << "Unable to send EOF";
+    }
+
+    pty()->waitForBytesWritten();
+}
+
 int Pty::foregroundProcessGroup() const
 {
     int foregroundPid = tcgetpgrp(pty()->masterFd());
