@@ -31,6 +31,7 @@
 // KDE
 #include <KAboutData>
 #include <KLocalizedString>
+#include <KCrash>
 #include <Kdelibs4ConfigMigrator>
 #include <Kdelibs4Migration>
 #include <kdbusservice.h>
@@ -106,6 +107,8 @@ extern "C" int Q_DECL_EXPORT kdemain(int argc, char* argv[])
 
     KAboutData::setApplicationData(about);
 
+    KCrash::initialize();
+
     QCommandLineParser parser;
     parser.setApplicationDescription(about.shortDescription());
     parser.addHelpOption();
@@ -158,15 +161,16 @@ extern "C" int Q_DECL_EXPORT kdemain(int argc, char* argv[])
     // of Konsole is started.
     QObject::connect(&dbusService, &KDBusService::activateRequested, &konsoleApp, &Application::slotActivateRequested);
 
-    if (!konsoleApp.newInstance()) {
-        // An argument that printed something and mean we should just quit was passed.
+    if (app->isSessionRestored()) {
+        restoreSession(konsoleApp);
+    } else if (!konsoleApp.newInstance()) {
+        // Do not finish starting Konsole
+        // 1. An argument was given to just printed info
+        // 2. An invalid situation ocurred
         delete app;
         return 0;
     }
 
-    if (app->isSessionRestored())
-        restoreSession(konsoleApp);
-
     // Since we've allocated the QApplication on the heap for the KDBusService workaround,
     // we need to delete it manually before returning from main().
     int ret = app->exec();
